@@ -77,6 +77,8 @@ MonitorsGround::MonitorsGround(int activateHeight, QWidget *parent)
     m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
     m_effectiveTimer->setSingleShot(true);
     connect(m_effectiveTimer, &QTimer::timeout, this, [=]() {
+        m_nEffectiveTime = 2;
+        m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
         Q_EMIT setEffectiveReminderVisible(false, m_nEffectiveTime);
         for (auto mon : m_model->monitorList()) {
             disconnect(mon, &Monitor::geometryChanged, this, &MonitorsGround::onGeometryChanged);
@@ -139,7 +141,7 @@ void MonitorsGround::setModel(DisplayModel *model, Monitor *moni)
     QTimer::singleShot(1, this, [=](){
         if (!m_isSingleDisplay) {
             updateScale();
-        }    
+        }
         resetMonitorsView();
     });
 }
@@ -199,7 +201,7 @@ void MonitorsGround::onRotateChanged()
 void MonitorsGround::onCurrentModeChanged()
 {
     onResize();
-    if (m_setMergeMode)
+    if (m_setMergeMode || m_isSingleDisplay)
         return;
 
     Monitor *mon = qobject_cast<Monitor*>(sender());
@@ -211,7 +213,7 @@ void MonitorsGround::onCurrentModeChanged()
           }
     }
 
-   executemultiScreenAlgo(false);
+    executemultiScreenAlgo(false);
 }
 
 
@@ -222,6 +224,13 @@ void MonitorsGround::executemultiScreenAlgo(const bool isRebound)
 
     bool isRestore = false;
     multiScreenSortAlgo(isRestore, isRebound);
+
+    //需要重新拼接
+    if(m_movingItem->getReSplicing()) {
+        m_movingItem->setReSplicing(false);
+        multiScreenSortAlgo(isRestore, true);
+    }
+
     if (isRestore == true)
         return;
 
@@ -230,6 +239,8 @@ void MonitorsGround::executemultiScreenAlgo(const bool isRebound)
     updateConnectedState();
 
     //显示设置生效倒计时提示框
+    m_nEffectiveTime = isRebound ? 2 : 0;
+    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
@@ -523,12 +534,23 @@ QPointF MonitorsGround::multiScreenSortAlgo(bool &isRestore, const bool isReboun
     });
 
     //自动回弹的触发条件: 1. 一个屏幕完全包含另一个屏的时候 2. 一个屏幕剩下的屏幕集合所包围
-    if (lstShelterItems.size() > 0 && isRebound) {
+    if (lstShelterItems.size() > 0) {
         if (isMove) {
-            autoRebound();
-            qDebug() << "自动回弹流程触发! == " << lstShelterItems.size();
-            isRestore = true;
-            return QPointF(0.0,0.0);
+
+            if (isRebound) {
+                autoRebound();
+                qDebug() << "自动回弹流程触发! == " << lstShelterItems.size();
+                isRestore = true;
+                return QPointF(0.0,0.0);
+            }
+            else {
+                //当改变方向时出现覆盖多个块的情况，会触发自动会弹流程，但是改变方向的上一个操作状态不存在或者说回弹到上一个状态没有意义，会导致屏幕重叠现象
+                //如果是由于方向改变导致的重叠，那就将此块移动到items外接矩形的左下角再重新执行拼接算法。
+                m_movingItem->moveBy(scene()->itemsBoundingRect().right() - m_movingItem->mapToScene(m_movingItem->boundingRect().bottomLeft()).x(),
+                                     scene()->itemsBoundingRect().bottom() - m_movingItem->mapToScene(m_movingItem->boundingRect().topLeft()).y());
+                m_movingItem->setReSplicing(true);
+                return QPointF(0.0,0.0);
+            }
         }
     }
     else { //没有完全重合的情况处理逻辑
@@ -1326,6 +1348,8 @@ void MonitorsGround::onRequestKeyPress(MonitorProxyWidget *pw, int keyValue)
     updateConnectedState();
     onResize();
 
+    m_nEffectiveTime = 2;
+    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
