@@ -40,6 +40,7 @@
 using namespace DCC_NAMESPACE;
 
 const QString ChangeLogFile = "/usr/share/deepin/release-note/UpdateInfo.json";
+const QString ChangeLogDic = "/usr/share/deepin/";
 
 // 系统补丁标识
 const QString DDEId = "dde";
@@ -91,6 +92,7 @@ UpdateWorker::UpdateWorker(UpdateModel *model, QObject *parent)
     : QObject(parent)
     , m_model(model)
     , m_checkUpdateJob(nullptr)
+    , m_fixErrorJob(nullptr)
     , m_sysUpdateDownloadJob(nullptr)
     , m_safeUpdateDownloadJob(nullptr)
     , m_unknownUpdateDownloadJob(nullptr)
@@ -114,7 +116,9 @@ UpdateWorker::UpdateWorker(UpdateModel *model, QObject *parent)
     , m_iconThemeState("")
     , m_backupStatus(BackupStatus::NoBackup)
     , m_backupingClassifyType(ClassifyUpdateType::Invalid)
-    , m_releaseNoteStatus("")
+    , m_releaseNoteJobStatus("")
+    , m_releaseNoteUpdated(false)
+    , m_fileSystemWatcher(new QFileSystemWatcher(this))
 {
 
 }
@@ -128,7 +132,12 @@ UpdateWorker::~UpdateWorker()
     deleteJob(m_unknownUpdateDownloadJob);
     deleteJob(m_unknownUpdateInstallJob);
     deleteJob(m_checkUpdateJob);
-	deleteJob(m_releaseNoteInstallJob);
+    deleteJob(m_releaseNoteInstallJob);
+    deleteJob(m_fixErrorJob);
+    if (m_fileSystemWatcher != nullptr) {
+        delete m_fileSystemWatcher;
+        m_fileSystemWatcher = nullptr;
+    }
 }
 
 void UpdateWorker::init()
@@ -167,7 +176,13 @@ void UpdateWorker::init()
     connect(m_updateInter, &__Updater::AutoInstallUpdateTypeChanged, m_model, &UpdateModel::setAutoInstallUpdateType);
     connect(m_updateInter, &__Updater::MirrorSourceChanged, m_model, &UpdateModel::setDefaultMirror);
     connect(m_updateInter, &UpdateInter::AutoCheckUpdatesChanged, m_model, &UpdateModel::setAutoCheckUpdates);
-    connect(m_managerInter, &ManagerInter::UpdateModeChanged, m_model, &UpdateModel::setUpdateMode);
+    connect(m_managerInter, &ManagerInter::UpdateModeChanged, m_model, [ = ](qulonglong value) {
+        m_model->setUpdateMode(value);
+        m_updateInter->setSync(true);
+        QMap<QString, QStringList> updatablePackages = m_updateInter->classifiedUpdatablePackages();
+        m_updateInter->setSync(false);
+        checkUpdatablePackages(updatablePackages);
+    });
     connect(m_updateInter, &UpdateInter::UpdateNotifyChanged, m_model, &UpdateModel::setUpdateNotify);
     connect(m_updateInter, &UpdateInter::ClassifiedUpdatablePackagesChanged, this, &UpdateWorker::onClassifiedUpdatablePackagesChanged);
 
@@ -282,25 +297,23 @@ void UpdateWorker::activate()
                                          "com.deepin.license.Info", "LicenseStateChange",
                                          this, SLOT(licenseStateChangeSlot()));
 
-    QFutureWatcher<QStringList> *packagesWatcher = new QFutureWatcher<QStringList>();
+    QFutureWatcher<QMap<QString, QStringList>> *packagesWatcher = new QFutureWatcher<QMap<QString, QStringList>>();
     connect(packagesWatcher, &QFutureWatcher<QStringList>::finished, this, [ = ] {
-        QStringList updatablePackages = std::move(packagesWatcher->result());
-        qDebug() << "UpdatablePackages = " << updatablePackages.count();
-        m_model->isUpdatablePackages(updatablePackages.count() > UPDATE_PACKAGE_SIZE);
+        QMap<QString, QStringList> updatablePackages = std::move(packagesWatcher->result());
+        checkUpdatablePackages(updatablePackages);
         packagesWatcher->deleteLater();
     });
 
-    packagesWatcher->setFuture(QtConcurrent::run([ = ]() -> QStringList {
-        QDBusInterface Interface("com.deepin.lastore", "/com/deepin/lastore",
-                                 "com.deepin.lastore.Updater",
-                                 QDBusConnection::systemBus());
-        if (!Interface.isValid())
-        {
-            qDebug() << "com.deepin.license error ," << Interface.lastError().name();
-            return {};
+    packagesWatcher->setFuture(QtConcurrent::run([ = ]() -> QMap<QString, QStringList> {
+        m_updateInter->setSync(true);
+        QMap<QString, QStringList> map;
+        if (!m_updateInter->isValid()) {
+            qDebug() << "com.deepin.license error ," << m_updateInter->lastError().name();
+            return map;
         }
-
-        return Interface.property("UpdatablePackages").toStringList();
+        map = m_updateInter->classifiedUpdatablePackages();
+        m_updateInter->setSync(false);
+        return map;
     }));
 
     QFutureWatcher<QString> *iconWatcher = new QFutureWatcher<QString>();
@@ -370,15 +383,23 @@ void UpdateWorker::setUpdateInfo()
     m_updateInter->setSync(false);
     m_managerInter->setSync(false);
 
-    QFile logFile(ChangeLogFile);
-    bool hasReleaseNote = logFile.exists();
-    if ((m_systemPackages.contains("uos-release-note") || !hasReleaseNote)) {
+    bool hasReleaseNote = QFile::exists(ChangeLogFile);
+    if ((m_systemPackages.contains("uos-release-note") || !hasReleaseNote) && hasRepositoriesUpdates()) {
         qDebug() << "install uos-release-note";
         QEventLoop eventLoop;
+        m_releaseNoteUpdated = false;
         QTimer::singleShot(30000, &eventLoop, &QEventLoop::quit);
         connect(this, &UpdateWorker::releaseNoteInstallCompleted, &eventLoop, &QEventLoop::quit);
+        qDebug() << "ChangeLogFile" << ChangeLogFile;
         eventLoop.exec();
+    } else {
+        m_releaseNoteUpdated = true;
     }
+    if (m_fileSystemWatcher != nullptr) {
+        delete m_fileSystemWatcher;
+        m_fileSystemWatcher = nullptr;
+    }
+
 
     qDebug() << "systemUpdate packages:" <<  m_systemPackages;
     qDebug() << "safeUpdate packages:" <<  m_safePackages;
@@ -389,6 +410,7 @@ void UpdateWorker::setUpdateInfo()
         return;
     }
 
+    qDebug() << "uos-releasenote :" << getReleaseNoteStatus();
     int updateCount = m_systemPackages.count() + m_safePackages.count() + m_unknownPackages.count();
     if (updateCount < 1) {
         QFile file("/tmp/.dcc-update-successd");
@@ -437,7 +459,9 @@ QMap<ClassifyUpdateType, UpdateItemInfo *> UpdateWorker::getAllUpdateInfo()
     updateDailyKeyMap.insert(ClassifyUpdateType::SecurityUpdate, "safeUpdateInfo");
     updateDailyKeyMap.insert(ClassifyUpdateType::UnknownUpdate, "otherUpdateInfo");
 
-    if (m_systemPackages.count() > 0) {
+    quint64 updateMode = m_model->updateMode();
+
+    if (m_systemPackages.count() > 0 && (updateMode & ClassifyUpdateType::SystemUpdate)) {
         UpdateItemInfo *systemItemInfo = new UpdateItemInfo;
         systemItemInfo->setName(tr("System Updates"));
         systemItemInfo->setExplain(tr("Fixed some known bugs and security vulnerabilities"));
@@ -445,7 +469,7 @@ QMap<ClassifyUpdateType, UpdateItemInfo *> UpdateWorker::getAllUpdateInfo()
         resultMap.insert(ClassifyUpdateType::SystemUpdate, systemItemInfo);
     }
 
-    if (m_safePackages.count() > 0) {
+    if (m_safePackages.count() > 0 && (updateMode & ClassifyUpdateType::SecurityUpdate)) {
         UpdateItemInfo  *safeItemInfo = new UpdateItemInfo;
         safeItemInfo->setName(tr("Security Updates"));
         safeItemInfo->setExplain(tr("Fixed some known bugs and security vulnerabilities"));
@@ -453,15 +477,15 @@ QMap<ClassifyUpdateType, UpdateItemInfo *> UpdateWorker::getAllUpdateInfo()
         resultMap.insert(ClassifyUpdateType::SecurityUpdate, safeItemInfo);
     }
 
-    if (m_unknownPackages.count() > 0) {
+    if (m_unknownPackages.count() > 0 && (updateMode & ClassifyUpdateType::UnknownUpdate)) {
         UpdateItemInfo *unkownItemInfo = new UpdateItemInfo;
-        unkownItemInfo->setName(tr("Unknown Apps Updates"));
+        unkownItemInfo->setName(tr("Third-party Repositories"));
         setUpdateItemDownloadSize(unkownItemInfo, m_unknownPackages);
         resultMap.insert(ClassifyUpdateType::UnknownUpdate, unkownItemInfo);
     }
 
-    if (m_releaseNoteStatus == "failed") {
-        qWarning() << "releaseNoteStatus = " << m_releaseNoteStatus;
+    if (m_releaseNoteJobStatus == "failed") {
+        qWarning() << "releaseNoteStatus = " << m_releaseNoteJobStatus;
         return resultMap;
     }
 
@@ -575,18 +599,9 @@ void UpdateWorker::onSmartMirrorServiceIsValid(bool isvalid)
 //处于以下状态时，就不能再去设置其他更新的状态了，直接显示对应错误提示
 bool UpdateWorker::getNotUpdateState()
 {
-    bool ret = true;
     UpdatesStatus state = m_model->status();
 
-    if (state == UpdatesStatus::NoSpace ||
-            state == UpdatesStatus::NoNetwork ||
-            state == UpdatesStatus::RecoveryBackupFailed ||
-            state == UpdatesStatus::DeependenciesBrokenError ||
-            state == UpdatesStatus::UpdateFailed) {
-        ret = false;
-    }
-
-    return ret;
+    return state != UpdatesStatus::RecoveryBackupFailed && state != UpdatesStatus::UpdateFailed;
 }
 
 void UpdateWorker::resetDownloadInfo(bool state)
@@ -968,6 +983,10 @@ void UpdateWorker::setReleaseNoteInstallJob(const QString &jobPath)
             m_managerInter->CleanJob(m_releaseNoteInstallJob->id());
             deleteJob(m_releaseNoteInstallJob);
         }
+
+        if (status == "ready") {
+            listenReleaseNoteFile();
+        }
     });
 
     m_releaseNoteInstallJob->StatusChanged(m_releaseNoteInstallJob->status());
@@ -1028,6 +1047,9 @@ void UpdateWorker::setAutoCleanCache(const bool autoCleanCache)
 
 void UpdateWorker::onJobListChanged(const QList<QDBusObjectPath> &jobs)
 {
+    if (!hasRepositoriesUpdates()) {
+        return;
+    }
     for (const auto &job : jobs) {
         m_jobPath = job.path();
 
@@ -1065,8 +1087,9 @@ void UpdateWorker::onJobListChanged(const QList<QDBusObjectPath> &jobs)
             setDistUpgradeJob(m_jobPath, ClassifyUpdateType::SecurityUpdate);
         } else if (id == "unknown_upgrade" && m_unknownUpdateInstallJob == nullptr) {
             setDistUpgradeJob(m_jobPath, ClassifyUpdateType::UnknownUpdate);
-        } else if (id.contains("install") && jobInter.packages().contains("uos-release-note")) {
+        } else if (id.contains("install") && jobInter.packages().at(0) == "uos-release-note") {
             qDebug() << "jobInter :uos-release-note status: " << jobInter.status();
+            qDebug() << "jobInter :uos-release-note packages: " << jobInter.packages();
             setReleaseNoteInstallJob(m_jobPath);
         }
     }
@@ -1149,24 +1172,14 @@ void UpdateWorker::onCheckUpdateStatusChanged(const QString &value)
 
 void UpdateWorker::checkDiskSpace(const QString &jobDescription)
 {
-    UpdateJobErrorMessage errorMessage = analyzeJobErrorMessage(jobDescription);
     qDebug() << "job description: " << jobDescription;
 
-    if (errorMessage.jobErrorType == "unmetDependencies" ||
-            !m_lastoresessionHelper->IsDiskSpaceSufficient()) {
-        m_model->setStatus(UpdatesStatus::NoSpace, __LINE__);
-    } else if (errorMessage.jobErrorType == "fetchFailed") {
-        m_model->setStatus(UpdatesStatus::NoNetwork, __LINE__);
-    } else if (errorMessage.jobErrorType == "insufficientSpace") {
-        m_model->setStatus(UpdatesStatus::DeependenciesBrokenError, __LINE__);
-    } else {
-        m_model->setStatus(UpdatesStatus::UpdateFailed, __LINE__);
-        qDebug() << Q_FUNC_INFO << "UpdateFailed , jobDescription : " << jobDescription;
-    }
+    m_model->setClassityUpdateJonError(ClassifyUpdateType::Invalid, analyzeJobErrorMessage(jobDescription));
+    m_model->setStatus(UpdatesStatus::UpdateFailed, __LINE__);
+    qDebug() << Q_FUNC_INFO << "UpdateFailed , jobDescription : " << jobDescription;
+
     //以上错误均需重置更新信息
-    if (m_model->status() == UpdatesStatus::UpdateFailed) {
-        resetDownloadInfo();
-    }
+    resetDownloadInfo();
 }
 
 void UpdateWorker::setBatteryPercentage(const BatteryPercentageInfo &info)
@@ -1432,35 +1445,32 @@ void UpdateWorker::onRequestOpenAppStore()
     qDebug() << reply.errorMessage();
 }
 
-UpdateJobErrorMessage UpdateWorker::analyzeJobErrorMessage(QString jobDescription)
+UpdateErrorType UpdateWorker::analyzeJobErrorMessage(QString jobDescription)
 {
-    UpdateJobErrorMessage result;
-    result.jobErrorType = "InvalidJobType";
-    result.jobErrorMessage = "";
     QJsonParseError err_rpt;
     QJsonDocument jobErrorMessage = QJsonDocument::fromJson(jobDescription.toUtf8(), &err_rpt);
 
     if (err_rpt.error != QJsonParseError::NoError) {
-        qDebug() << "更新日志信息JSON格式错误";
-        return result;
+        qDebug() << "更新失败JSON格式错误";
+        return UpdateErrorType::NoError;
     }
     const QJsonObject &object = jobErrorMessage.object();
     QString errorType =  object.value("ErrType").toString();
     if (errorType.contains("fetchFailed", Qt::CaseInsensitive) || errorType.contains("IndexDownloadFailed", Qt::CaseInsensitive)) {
-        result.jobErrorType = "fetchFailed";
-        result.jobErrorMessage = tr("Network error");
-    } else if (errorType.contains("unmetDependencies", Qt::CaseInsensitive) || errorType.contains("dependenciesBroken", Qt::CaseInsensitive)) {
-        result.jobErrorType = "unmetDependencies";
-        result.jobErrorMessage = tr("Dependency error");
-    } else if (errorType.contains("insufficientSpace", Qt::CaseInsensitive)) {
-        result.jobErrorType = "insufficientSpace";
-        result.jobErrorMessage = tr("Insufficient disk space");
-    } else {
-        result.jobErrorType = "unknown";
-        result.jobErrorMessage = tr("Update failed");
+        return UpdateErrorType::NoNetwork;
+
+    }
+    if (errorType.contains("unmetDependencies", Qt::CaseInsensitive) || errorType.contains("dependenciesBroken", Qt::CaseInsensitive)) {
+        return UpdateErrorType::DeependenciesBrokenError;
+    }
+    if (errorType.contains("insufficientSpace", Qt::CaseInsensitive)) {
+        return UpdateErrorType::NoSpace;
+    }
+    if (errorType.contains("interrupted", Qt::CaseInsensitive)) {
+        return UpdateErrorType::DpkgInterrupted;
     }
 
-    return result;
+    return UpdateErrorType::UnKnown;
 }
 
 void UpdateWorker::onClassityDownloadStatusChanged(const ClassifyUpdateType type, const QString &value)
@@ -1529,17 +1539,82 @@ QString UpdateWorker::getClassityUpdateDownloadJobName(ClassifyUpdateType update
     return  value;
 }
 
+void UpdateWorker::listenReleaseNoteFile()
+{
+    if (m_fileSystemWatcher == nullptr) {
+        m_fileSystemWatcher = new QFileSystemWatcher;
+    }
+    if (QFile::exists(ChangeLogFile)) {
+        m_fileSystemWatcher->addPath(ChangeLogFile);
+        connect(m_fileSystemWatcher, &QFileSystemWatcher::fileChanged, this, [ = ](const QString & path) {
+            qDebug() << "fileChanged    --" << path;
+            m_releaseNoteUpdated = true;
+            setReleaseNoteStatus(m_releaseNoteJobStatus);
+        });
+        return;
+    }
+
+    QDir dir(ChangeLogDic + "release-note");
+    QString listenDir = dir.exists() ? (ChangeLogDic + "release-note") : ChangeLogDic;
+    m_fileSystemWatcher->addPath(listenDir);
+    connect(m_fileSystemWatcher, &QFileSystemWatcher::directoryChanged, this, [ = ](const QString & path) {
+        qDebug() << "directoryChangedpath :" << path;
+        QDir dir(ChangeLogDic + "release-note");
+        if (dir.exists()) {
+            if (m_fileSystemWatcher->directories().contains(ChangeLogDic)) {
+                m_fileSystemWatcher->removePath(ChangeLogDic);
+            }
+            if (!m_fileSystemWatcher->directories().contains(ChangeLogDic + "release-note")) {
+                m_fileSystemWatcher->addPath(ChangeLogDic + "release-note");
+            }
+            if (QFile::exists(ChangeLogFile)) {
+                m_releaseNoteUpdated = true;
+                setReleaseNoteStatus(m_releaseNoteJobStatus);
+            }
+        }
+    });
+
+}
+
+void UpdateWorker::checkUpdatablePackages(const QMap<QString, QStringList> &updatablePackages)
+{
+    qDebug() << "UpdatablePackages = " << updatablePackages.count();
+    QMap<ClassifyUpdateType, QString> keyMap;
+    keyMap.insert(ClassifyUpdateType::SystemUpdate, SystemUpdateType);
+    keyMap.insert(ClassifyUpdateType::UnknownUpdate, UnknownUpdateType);
+    keyMap.insert(ClassifyUpdateType::SecurityUpdate, SecurityUpdateType);
+    bool showUpdateNotify = false;
+    for (auto item : keyMap.keys()) {
+        if ((m_model->updateMode() & static_cast<unsigned>(item)) && updatablePackages.value(keyMap.value(item)).count() > UPDATE_PACKAGE_SIZE) {
+            showUpdateNotify = true;
+            break;
+        }
+    }
+    m_model->isUpdatablePackages(showUpdateNotify);
+}
+
 QString UpdateWorker::getReleaseNoteStatus() const
 {
-    return m_releaseNoteStatus;
+    return m_releaseNoteJobStatus;
 }
 
 void UpdateWorker::setReleaseNoteStatus(const QString &releaseNoteStatus)
 {
-    m_releaseNoteStatus = releaseNoteStatus;
-    if (m_releaseNoteStatus == "success" || m_releaseNoteStatus == "succeed" || m_releaseNoteStatus == "failed") {
+    m_releaseNoteJobStatus = releaseNoteStatus;
+
+    if (m_releaseNoteJobStatus == "failed") {
         Q_EMIT releaseNoteInstallCompleted();
     }
+
+    if (m_releaseNoteUpdated && m_releaseNoteJobStatus == "end") {
+        Q_EMIT releaseNoteInstallCompleted();
+    }
+}
+
+bool UpdateWorker::hasRepositoriesUpdates()
+{
+    quint64 mode = m_model->updateMode();
+    return (mode & ClassifyUpdateType::SystemUpdate) || (mode & ClassifyUpdateType::UnknownUpdate) || (mode & ClassifyUpdateType::SecurityUpdate);
 }
 
 void UpdateWorker::onClassifiedUpdatablePackagesChanged(QMap<QString, QStringList> packages)
@@ -1556,6 +1631,41 @@ void UpdateWorker::onClassifiedUpdatablePackagesChanged(QMap<QString, QStringLis
     if (m_unknownPackages.count() == 0) {
         m_model->setClassifyUpdateTypeStatus(ClassifyUpdateType::UnknownUpdate, UpdatesStatus::Default);
     }
+    checkUpdatablePackages(packages);
+}
+
+void UpdateWorker::onFixError(const ClassifyUpdateType &updateType, const QString &errorType)
+{
+    m_fixErrorUpdate.append(updateType);
+    if (m_fixErrorJob != nullptr) {
+        return;
+    }
+    QDBusInterface lastoreManager("com.deepin.lastore",
+                                  "/com/deepin/lastore",
+                                  "com.deepin.lastore.Manager",
+                                  QDBusConnection::systemBus());
+    if (!lastoreManager.isValid()) {
+        qDebug() << "com.deepin.license error ," << lastoreManager.lastError().name();
+        return;
+    }
+
+
+    QDBusReply<QDBusObjectPath> reply = lastoreManager.call("FixError", errorType);
+    if (reply.isValid()) {
+        QString path = reply.value().path();
+        m_fixErrorJob = new JobInter("com.deepin.lastore", path, QDBusConnection::systemBus());
+        connect(m_fixErrorJob, &JobInter::StatusChanged, this, [ = ](const QString status) {
+            if (status == "succeed" || status == "failed" || status == "end") {
+                qDebug() << "m_fixErrorJob ---status :" << status;
+                for (auto type : m_fixErrorUpdate) {
+                    distUpgrade(type);
+                }
+                m_fixErrorUpdate.clear();
+                deleteJob(m_fixErrorJob);
+            }
+        });
+    }
+
 }
 
 void UpdateWorker::setUpdateItemDownloadSize(UpdateItemInfo *updateItem,  QStringList packages)
@@ -1572,5 +1682,18 @@ void UpdateWorker::setUpdateItemDownloadSize(UpdateItemInfo *updateItem,  QStrin
     });
 }
 
+void UpdateWorker::onRequestLastoreHeartBeat()
+{
+    QDBusInterface lastoreManager("com.deepin.lastore",
+                                  "/com/deepin/lastore",
+                                  "com.deepin.lastore.Updater",
+                                  QDBusConnection::systemBus());
+    if (!lastoreManager.isValid()) {
+        qDebug() << "com.deepin.license error ," << lastoreManager.lastError().name();
+        return;
+    }
+    lastoreManager.asyncCall("GetCheckIntervalAndTime");
+}
+
 }
 }
