@@ -334,8 +334,6 @@ void MainWindow::initAllModule(const QString &m)
     m_modules = {
         { new LoginOptionsModule(this), tr("Biometric Authentication")},
         { new AccountsModule(this), tr("Accounts")},
-        //~ contents_path /cloudsync/Cloud Sync
-        { new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "Union ID"},
         { new DisplayModule(this), tr("Display")},
         { new TouchscreenModule(this), tr("Touch Screen")},
         { new DefaultAppsModule(this), tr("Default Applications")},
@@ -352,7 +350,10 @@ void MainWindow::initAllModule(const QString &m)
         { new SystemInfoModule(this), tr("System Info")},
         { new CommonInfoModule(this), tr("General Settings")},
     };
-
+    // V20 对Deepinid 进行差异化处理  UnionID 走插件化
+    if (!IsProfessionalSystem) {
+         m_modules.insert(3, {new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "Union ID"});
+    }
     //读取加载一级菜单的插件
     if (InsertPlugin::instance(this, this)->updatePluginInfo("mainwindow"))
         InsertPlugin::instance()->pushPlugin(m_modules);
@@ -424,6 +425,9 @@ void MainWindow::updateWinsize(QRect rect)
     if (!qApp->screens().contains(m_primaryScreen))
         return;
 
+    if(this->isMaximized())
+        return;
+
     int w = m_primaryScreen->geometry().width();
     int h = m_primaryScreen->geometry().height();
     if (rect.width() && rect.height()) {
@@ -439,7 +443,7 @@ void MainWindow::updateWinsize(QRect rect)
         this->setGeometry(x(), y(), WidgetMinimumWidth, height());
     if (height() > WidgetMinimumHeight)
         this->setGeometry(x(), y(), width(), WidgetMinimumHeight);
-
+    this->titlebar()->updateGeometry();
     move(QPoint(m_primaryScreen->geometry().left() + (m_primaryScreen->geometry().width() - this->geometry().width()) / 2,
                 m_primaryScreen->geometry().top() + (m_primaryScreen->geometry().height() - this->geometry().height()) / 2));
 }
@@ -448,6 +452,7 @@ void MainWindow::updateModuleVisible()
 {
     m_hideModuleNames = m_moduleSettings->get(GSETTINGS_HIDE_MODULE).toStringList();
     for (auto i : m_modules) {
+
         if (m_hideModuleNames.contains((i.first->name()))) {
             setModuleVisible(i.second, false);
         } else if (i.first->deviceUnavailabel()) {
@@ -633,6 +638,8 @@ void MainWindow::setModuleSubscriptVisible(const QString &module, bool bIsDispla
             m_pair.first->setVisible(bIsDisplay);
             if (bIsDisplay) {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(ActionIconSize + 15, 0, 0, 0)), Dtk::MarginsRole);
+                if(m_hideModuleNames.contains(module))
+                    m_navView->setRowHidden(index, true);
             } else {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(0, 0, 0, 0)), Dtk::MarginsRole);
             }
