@@ -25,6 +25,7 @@
 #include "modules/accounts/usermodel.h"
 #include "modules/accounts/removeuserdialog.h"
 #include "window/gsettingwatcher.h"
+#include "window/dconfigwatcher.h"
 
 #include <DIconButton>
 #include <DWarningButton>
@@ -63,7 +64,7 @@ using namespace DCC_NAMESPACE::accounts;
 #define GSETTINGS_EFFECTIVE_DAY_VISIBLE "effectiveDayVisible"
 
 AccountSpinBox::AccountSpinBox(QWidget *parent)
-    :DSpinBox(parent)
+    : DSpinBox(parent)
 {
 }
 
@@ -98,12 +99,12 @@ AccountsDetailWidget::AccountsDetailWidget(User *user, UserModel *model, QWidget
     , m_groupListView(nullptr)
     , m_groupItemModel(nullptr)
     , m_avatarLayout(new QHBoxLayout)
-    , m_tipDialog(nullptr)
     , m_deleteAccount(new DWarningButton)
     , m_modifyPassword(new QPushButton)
     , m_gsettings(new QGSettings("com.deepin.dde.control-center", QByteArray(), this))
     , m_scrollArea(new QScrollArea)
     , m_curLoginUser(nullptr)
+    , m_bindStatusLabel(new QLabel(tr("Go to Settings"), this))
 {
     m_isServerSystem = IsServerSystem;
     //整体布局
@@ -158,14 +159,14 @@ AccountsDetailWidget::~AccountsDetailWidget()
     GSettingWatcher::instance()->erase("accountUserFullnamebtn", m_fullNameBtn);
 }
 
-bool AccountsDetailWidget::getOtherUserAutoLogin()
+QString AccountsDetailWidget::getOtherUserAutoLogin()
 {
-    for(auto user : m_userModel->userList()) {
+    for (auto user : m_userModel->userList()) {
         if (user->name() != m_curUser->name() && user->autoLogin()) {
-            return false;
+            return user->name();
         }
     }
-    return true;
+    return "";
 }
 
 //删除账户
@@ -333,11 +334,18 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
         m_inputLineEdit->lineEdit()->setFocus();
     });
 
-    for(auto user : m_userModel->userList()) {
+    for (auto user : m_userModel->userList()) {
         if (user->name() == m_userModel->getCurrentUserName()) {
             m_curLoginUser = user;
+            // 结束后续没必要的循环
+            break;
         }
     }
+
+    if (m_userModel->getIsSecurityHighLever() && m_curLoginUser->securityLever() != SecurityLever::Sysadm && !m_curUser->isCurrentUser()) {
+        avatar->setEnabled(false) ;
+    }
+
 }
 
 void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
@@ -370,13 +378,37 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
     pwWidget->setLayout(pwHLayout);
 
     //~ contents_path /accounts/Validity Days
-    QLabel *vlidityLabel= new QLabel(tr("Validity Days"));
+    QLabel *vlidityLabel = new QLabel(tr("Validity Days"));
     pwHLayout->addWidget(vlidityLabel, 0, Qt::AlignLeft);
     auto validityDaysBox = new AccountSpinBox();
     validityDaysBox->lineEdit()->setValidator(new QRegularExpressionValidator(QRegularExpression("[1-9]\\d{0,4}/^[1-9]\\d*$/"), validityDaysBox->lineEdit()));
     validityDaysBox->lineEdit()->setPlaceholderText("99999");
-    validityDaysBox->setRange(1,99999);
-    pwHLayout->addWidget(validityDaysBox,0, Qt::AlignRight);
+    validityDaysBox->setRange(1, 99999);
+    pwHLayout->addWidget(validityDaysBox, 0, Qt::AlignRight);
+
+    // 设置安全问题
+    auto sqHLayout = new QHBoxLayout;
+    sqHLayout->setContentsMargins(10, 0, 10, 0);
+    auto securityQuestionsWidget = new SettingsItem;
+    loginGrp->appendItem(securityQuestionsWidget);
+    securityQuestionsWidget->setLayout(sqHLayout);
+
+    QLabel *securityQuestionsLabel= new QLabel(tr("Security Questions"));
+    sqHLayout->addWidget(securityQuestionsLabel, 0, Qt::AlignLeft);
+    sqHLayout->addSpacing(108);
+    sqHLayout->addWidget(m_bindStatusLabel);
+    auto securityQuestionsButton = new DToolButton(securityQuestionsWidget);
+    QStyleOption opt;
+    securityQuestionsButton->setIcon(DStyleHelper(this->style()).standardIcon(DStyle::SP_ArrowEnter, &opt, nullptr));
+    sqHLayout->addWidget(securityQuestionsButton, 0, Qt::AlignRight);
+    securityQuestionsWidget->setVisible(false);
+
+    if (m_curUser->isCurrentUser())
+        DConfigWatcher::instance()->bind(DConfigWatcher::accounts, "securityQuestions", securityQuestionsWidget);
+
+    connect(securityQuestionsButton, &QPushButton::clicked, this, [this] {
+        Q_EMIT requestShowSecurityQuestionsSettings(m_curUser);
+    });
 
     connect(validityDaysBox, qOverload<int>(&DSpinBox::valueChanged), this, [=](const int value) {
         validityDaysBox->setValue(value);
@@ -400,7 +432,7 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
 
     const bool isVisible = m_gsettings->get(GSETTINGS_EFFECTIVE_DAY_VISIBLE).toBool();
     pwWidget->setVisible(isVisible);
-    connect(m_gsettings, &QGSettings::changed, [=] (const QString &key){
+    connect(m_gsettings, &QGSettings::changed, [ = ](const QString &key) {
         if (key != GSETTINGS_EFFECTIVE_DAY_VISIBLE) {
             return;
         }
@@ -439,10 +471,23 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
     m_nopasswdLogin->setChecked(m_curUser->nopasswdLogin());
     //~ contents_path /accounts/Administrator
     m_asAdministrator->setTitle(tr("Administrator"));
-    m_asAdministrator->setChecked(m_curUser->userType() == User::UserType::Administrator);
+    m_asAdministrator->setChecked(isSystemAdmin(m_curUser));
+    if (m_userModel->getIsSecurityHighLever()) {
+        m_asAdministrator->setEnabled(false);
+
+        // 开启等保3级后如果当前登录的账户不是sysadm_u，则用户只能操作当前自己登录用户的界面
+        if (m_curLoginUser->securityLever() != SecurityLever::Sysadm && !isCurUser) {
+            validityDaysBox->setEnabled(false);
+            m_fullNameBtn->setEnabled(false);
+            m_deleteAccount->setEnabled(false);
+            m_modifyPassword->setEnabled(false);
+            m_autoLogin->switchButton()->setEnabled(false);
+            m_nopasswdLogin->switchButton()->setEnabled(false);
+        }
+    }
     //修改密码状态判断
     connect(m_gsettings, &QGSettings::changed, this, &AccountsDetailWidget::setModifyPwdBtnStatus);
-    connect(m_curUser, &User::onlineChanged, this, [=] {
+    connect(m_curUser, &User::onlineChanged, this, [ = ] {
         setModifyPwdBtnStatus("accountUserModifypasswd");
     });
     setModifyPwdBtnStatus("accountUserModifypasswd");
@@ -462,31 +507,21 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
     connect(m_curUser, &User::autoLoginChanged, m_autoLogin, &SwitchWidget::setChecked);
     connect(m_curUser, &User::nopasswdLoginChanged, m_nopasswdLogin, &SwitchWidget::setChecked);
     connect(m_autoLogin, &SwitchWidget::checkedChanged,
-            this, [ = ](const bool autoLogin) {
+    this, [ = ](const bool autoLogin) {
         if (autoLogin) {
-            if (getOtherUserAutoLogin()) {
+            const QString &existedAutoLoginUserName = getOtherUserAutoLogin();
+            if (existedAutoLoginUserName.isEmpty()) {
                 Q_EMIT requestSetAutoLogin(m_curUser, autoLogin);
             } else {
-                m_tipDialog = new DDialog(this);
-                m_tipDialog->setModal(true);
-                m_tipDialog->setAttribute(Qt::WA_DeleteOnClose);
-                m_tipDialog->setMessage(tr("Only one account can have \"Auto Login\" enabled. If proceeding,"\
-                                           " that option of other accounts will be disabled."));
-                m_tipDialog->addButton(tr("Cancel"), false, DDialog::ButtonRecommend);
-                m_tipDialog->addButton(tr("Enable"), true, DDialog::ButtonRecommend);
-                m_tipDialog->show();
-                connect(m_tipDialog, &DDialog::buttonClicked, this, [ = ](int index, const QString &text) {
-                    Q_UNUSED(text);
-                    if (!index) {
-                        m_tipDialog->close();
-                        m_autoLogin->setChecked(false);
-                    } else {
-                        Q_EMIT requestSetAutoLogin(m_curUser, autoLogin);
-                    }
-                });
-                connect(m_tipDialog, &DDialog::closed, this, [ = ] {
-                    m_autoLogin->setChecked(false);
-                });
+                DDialog *tipDialog = new DDialog(this);
+                tipDialog->setIcon(QIcon::fromTheme("dialog-warning"));
+                tipDialog->setModal(true);
+                tipDialog->setAttribute(Qt::WA_DeleteOnClose);
+                tipDialog->addButton(tr("OK"));
+                tipDialog->setMessage(tr("\"Auto Login\" can be enabled for only one account, please disable it for the account \"%1\" first").arg(existedAutoLoginUserName));
+                tipDialog->setFixedWidth(422);
+                tipDialog->show();
+                m_autoLogin->setChecked(false);
             }
         } else {
             Q_EMIT requestSetAutoLogin(m_curUser, autoLogin);
@@ -508,6 +543,8 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
     connect(m_asAdministrator, &SwitchWidget::checkedChanged, this, [ = ](const bool asAdministrator) {
         Q_EMIT requestSetAdministrator(m_curUser, asAdministrator);
     });
+    connect(m_curUser, &User::startSecurityQuestionsCheckReplied, this, &AccountsDetailWidget::onSecurityQuestionsCheckReplied);
+
 
 }
 
@@ -526,27 +563,36 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
         connect(m_userModel, &UserModel::noPassWordLoginVisableChanged, m_nopasswdLogin, &SwitchWidget::setVisible);
     }
 
-    auto adminCnt = [=]() {
+    auto adminCnt = [ = ]() {
         int adminCnt = 0;
-        for(auto user : m_userModel->userList()) {
-            if(user->userType() == User::UserType::Administrator)
+        if (m_userModel->getIsSecurityHighLever()) {
+            return 1;
+        }
+        for (auto user : m_userModel->userList()) {
+            if (user->userType() == User::UserType::Administrator)
                 adminCnt++;
         }
         return adminCnt;
     };
 
-    auto isOnlyAdmin = [=]() {                                  // 是最后一个管理员
-        return m_curUser->userType() == User::Administrator     // 是管理员
+    auto isOnlyAdmin = [ = ] {                                // 是最后一个管理员
+        return isSystemAdmin(m_curUser)                         // 是管理员
                && adminCnt() == 1;                              // 管理员只有一个
     };
 
-    auto deleteUserBtnEnable = [=]() {      // 可以删除用户
+    auto deleteUserBtnEnable = [ = ] {    // 可以删除用户
+        if (m_userModel->getIsSecurityHighLever()){
+            return m_curLoginUser->securityLever() == SecurityLever::Sysadm && !m_curUser->isCurrentUser();
+        }
         return !m_curUser->isCurrentUser()  // 不是当前用户
-                && !m_curUser->online()     // 未登录
-                && !isOnlyAdmin();          // 不是最后一个管理员
+               && !m_curUser->online()     // 未登录
+               && !isOnlyAdmin();          // 不是最后一个管理员
     };
 
-    auto asAdministratorEnable = [=]() {    // 可以切换账户类型
+    auto asAdministratorEnable = [ = ] {  // 可以切换账户类型
+        if (m_userModel->getIsSecurityHighLever()){
+            return m_curLoginUser->securityLever() == SecurityLever::Sysadm && !m_curUser->isCurrentUser();
+        }
         return !m_curUser->isCurrentUser()  // 不是当前用户
                && !m_curUser->online()      // 未登录
                && !isOnlyAdmin();           // 不是最后一个管理员
@@ -554,20 +600,24 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
 
     setDeleteBtnStatus("accountUserDeleteaccount", deleteUserBtnEnable());
 
-    connect(m_curUser, &User::onlineChanged, m_deleteAccount,
-            [=]() { m_deleteAccount->setEnabled(deleteUserBtnEnable()); });
-    connect(m_userModel, &UserModel::adminCntChange, m_deleteAccount,
-            [=]() { m_deleteAccount->setEnabled(deleteUserBtnEnable()); });
+    connect(m_curUser, &User::onlineChanged, m_deleteAccount, [ = ] {
+        m_deleteAccount->setEnabled(deleteUserBtnEnable());
+    });
+    connect(m_userModel, &UserModel::adminCntChange, m_deleteAccount, [ = ] {
+        m_deleteAccount->setEnabled(deleteUserBtnEnable());
+    });
 
-    connect(m_gsettings, &QGSettings::changed, m_deleteAccount, [=](const QString &key) {
+    connect(m_gsettings, &QGSettings::changed, m_deleteAccount, [ = ](const QString &key) {
         setDeleteBtnStatus(key, deleteUserBtnEnable());
     });
 
     m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable());
-    connect(m_curUser, &User::onlineChanged, m_asAdministrator,
-            [=]() { m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable()); });
-    connect(m_userModel, &UserModel::adminCntChange, m_asAdministrator,
-            [=]() { m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable()); });
+    connect(m_curUser, &User::onlineChanged, m_asAdministrator, [ = ] {
+        m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable());
+    });
+    connect(m_userModel, &UserModel::adminCntChange, m_asAdministrator, [ = ] {
+        m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable());
+    });
 
     if (!m_groupItemModel)
         return;
@@ -583,7 +633,7 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
     onGidChanged(m_curUser->gid());
     connect(m_curUser, &User::groupsChanged, this, &AccountsDetailWidget::changeUserGroup);
     connect(m_curUser, &User::gidChanged, this, &AccountsDetailWidget::onGidChanged);
-    connect(m_curLoginUser, &User::userTypeChanged, this, [=] {
+    connect(m_curLoginUser, &User::userTypeChanged, this, [ = ] {
         setModifyPwdBtnStatus("accountUserModifypasswd");
     });
 }
@@ -633,7 +683,7 @@ void AccountsDetailWidget::resetDelButtonState()
     m_deleteAccount->setEnabled(true);
 }
 
-void AccountsDetailWidget::onEditingFinished(bool isValid, const QString& userFullName)
+void AccountsDetailWidget::onEditingFinished(bool isValid, const QString &userFullName)
 {
     if (userFullName == m_curUser->fullname() || (!userFullName.isEmpty() && userFullName.simplified().isEmpty())) {
         m_inputLineEdit->lineEdit()->clearFocus();
@@ -649,15 +699,15 @@ void AccountsDetailWidget::onEditingFinished(bool isValid, const QString& userFu
     if (!userFullName.isEmpty()) {
         if (isValid) {
             m_inputLineEdit->setAlert(true);
-            m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+            m_inputLineEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_inputLineEdit, 2000);
             m_inputLineEdit->lineEdit()->selectAll();
             return;
         }
         QList<User *> userList = m_userModel->userList();
         for (User *user : userList) {
-            if (userFullName == user->fullname() || userFullName == user->name()) {
+            if ((userFullName == user->fullname() || userFullName == user->name()) && user != m_curUser) {
                 m_inputLineEdit->setAlert(true);
-                m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+                m_inputLineEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_inputLineEdit, 2000);
                 m_inputLineEdit->lineEdit()->selectAll();
                 return;
             }
@@ -666,7 +716,7 @@ void AccountsDetailWidget::onEditingFinished(bool isValid, const QString& userFu
         for (QString &group : groupList) {
             if (userFullName == group && userFullName != m_curUser->name()) {
                 m_inputLineEdit->setAlert(true);
-                m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+                m_inputLineEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_inputLineEdit, 2000);
                 m_inputLineEdit->lineEdit()->selectAll();
                 return;
             }
@@ -684,6 +734,11 @@ void AccountsDetailWidget::onEditingFinished(bool isValid, const QString& userFu
     Q_EMIT requestSetFullname(m_curUser, m_inputLineEdit->text());
 }
 
+void AccountsDetailWidget::onSecurityQuestionsCheckReplied(const QList<int> &questions)
+{
+    m_bindStatusLabel->setVisible(questions.isEmpty());
+}
+
 void AccountsDetailWidget::setDeleteBtnStatus(const QString &key, const bool &status)
 {
     if ("accountUserDeleteaccount" != key)
@@ -706,17 +761,30 @@ void AccountsDetailWidget::setModifyPwdBtnStatus(const QString &key)
         return;
 
     const QString btnStatus = m_gsettings->get(key).toString();
-
-    m_modifyPassword->setEnabled("Enabled" == btnStatus && ((!m_curUser->online() && m_curLoginUser->userType() == User::UserType::Administrator) || m_curUser->isCurrentUser()));
+    // 若选择当前登录的账户，则允许修改，选择其他账户，当前登录账户必需是管理员且其他账户未登录时才允许修改密码
+    m_modifyPassword->setEnabled("Enabled" == btnStatus && ((!m_curUser->online() && isSystemAdmin(m_curLoginUser)) || m_curUser->isCurrentUser()));
 
     m_modifyPassword->setVisible("Hidden" != btnStatus);
 }
 
+bool AccountsDetailWidget::isSystemAdmin(User *user)
+{
+    // 在关闭等保3级的时候如果有secadm为自动登陆情况下，用户可以自动登陆进来,导致找不到当前登陆用户，故这里需要判断下当前登陆用户是否为空
+    if(user == nullptr)
+        return false;
+
+    // 本地管理员账户不一定是等保三级的管理员账户，要区分判断
+    if (m_userModel->getIsSecurityHighLever())
+        return user->securityLever() == SecurityLever::Sysadm;
+
+    return user->userType() == User::UserType::Administrator;
+}
+
 void AccountsDetailWidget::userGroupClicked(const QModelIndex &index)
 {
     QStandardItem *item = m_groupItemModel->item(index.row(), index.column());
     //不可移除主组
-    if(nullptr == item || item->text() == m_groupName)
+    if (!item || item->text() == m_groupName)
         return;
 
     QStringList curUserGroup;
