@@ -32,7 +32,6 @@
 #include "widgets/titlelabel.h"
 
 #include <DLineEdit>
-#include <DDialog>
 #include <DWarningButton>
 #include <DToolButton>
 #include <DSpinBox>
@@ -90,12 +89,14 @@ public:
     void initBodyPart(QVBoxLayout *bodyLayout);
     void setAccountModel(dcc::accounts::UserModel *model);
     //获取其它用户是否开启自动登录开关
-    bool getOtherUserAutoLogin();
+    QString getOtherUserAutoLogin();
     void setDeleteBtnStatus(const QString &key, const bool &status);
     void setModifyPwdBtnStatus(const QString &key);
+    bool isSystemAdmin(dcc::accounts::User *user);
 
 Q_SIGNALS:
     void requestShowPwdSettings(dcc::accounts::User *user);
+    void requestShowSecurityQuestionsSettings(dcc::accounts::User *user);
     void requestSetAutoLogin(dcc::accounts::User *user, const bool autoLogin);
     void requestSetAdministrator(dcc::accounts::User *user, const bool asAdministrator);
     void requestNopasswdLogin(dcc::accounts::User *user, const bool nopasswdLogin);
@@ -108,10 +109,12 @@ Q_SIGNALS:
     void requsetSetPassWordAge(dcc::accounts::User *user, const int age);
     void noticeEnrollCompleted(QString username);
     void editingFinished(const QString& userFullName);
+    void requestSecurityQuestionsCheck(dcc::accounts::User *user);
 
 public Q_SLOTS:
     void resetDelButtonState();
     void onEditingFinished(bool isValid, const QString& userFullName);
+    void onSecurityQuestionsCheckReplied(const QList<int> &questions);
 
 protected:
     void initUserInfo(QVBoxLayout *layout);
@@ -142,13 +145,13 @@ private:
     dcc::widgets::SwitchWidget *m_asAdministrator;//作为管理员
     TitleLabel *m_accountSettingsTitle;//账户设置
     QHBoxLayout *m_avatarLayout;
-    DDialog *m_tipDialog;
     DWarningButton *m_deleteAccount;
     QPushButton *m_modifyPassword;
     QGSettings *m_gsettings;
     QScrollArea *m_scrollArea;
     QString m_groupName;
     dcc::accounts::User *m_curLoginUser;
+    QLabel *m_bindStatusLabel;
 };
 
 }   // namespace accounts
