@@ -59,6 +59,8 @@ QT_END_NAMESPACE
 namespace DCC_NAMESPACE {
 namespace accounts {
 
+const int PwdLimitLowestLevel = 1;
+
 //创建账户页面
 class CreateAccountPage : public QWidget
 {
@@ -98,6 +100,7 @@ Q_SIGNALS:
     void requestCreateUser(const dcc::accounts::User *user);
     void requestBack(DCC_NAMESPACE::accounts::AccountsWidget::ActionOption option = DCC_NAMESPACE::accounts::AccountsWidget::ClickCancel);
     void requestSetPasswordHint(dcc::accounts::User *, const QString &);
+    void requestCheckPwdLimitLevel();
 
 public Q_SLOTS:
     void setCreationResult(dcc::accounts::CreationResult *result);
@@ -107,8 +110,8 @@ protected:
 
 private Q_SLOTS:
     bool checkName();
-    bool checkFullname();
-    bool checkPassword(DPasswordEdit *edit);
+    bool checkFullname(bool showTips = true);
+    bool checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage, bool showTips = true);
 
 private:
     dcc::accounts::User *m_newUser;
