@@ -51,7 +51,7 @@ UserExperienceProgramWidget::UserExperienceProgramWidget(QWidget *parent)
     m_joinUeProgram->setTitle(tr("Join User Experience Program"));
 
     QString text = "";
-    QString http = IsCommunitySystem ? tr("https://www.deepin.org/en/agreement/privacy/") : tr("https://www.uniontech.com/agreement/privacy-en");
+    QString http = IsCommunitySystem ? tr("https://www.deepin.org/en/agreement/privacy/") : tr("https://www.uniontech.com/agreement/experience-en");
     if (IsCommunitySystem) {
         text = tr("<p>Joining User Experience Program means that you grant and authorize us to collect and use the information of your device, system and applications. "
                   "If you refuse our collection and use of the aforementioned information, do not join User Experience Program. "
@@ -59,8 +59,7 @@ UserExperienceProgramWidget::UserExperienceProgramWidget(QWidget *parent)
                .arg(http);
     } else {
         text = tr("<p>Joining User Experience Program means that you grant and authorize us to collect and use the information of your device, system and applications. "
-                  "If you refuse our collection and use of the aforementioned information, do not join User Experience Program. "
-                  "To know more about the management of your data, please refer to UnionTech OS Privacy Policy (<a href=\"%1\"> %1</a>).</p>")
+                  "If you refuse our collection and use of the aforementioned information, please do not join it. For the details of User Experience Program, please visit <a href=\"%1\"> %1</a>.</p>")
                .arg(http);
     }
 
