@@ -59,6 +59,9 @@ BrightnessWidget::BrightnessWidget(QWidget *parent)
     , m_settingsGroup(new SettingsGroup(nullptr, SettingsGroup::GroupBackground))
     , m_nightManual(new SwitchWidget(this))
     , m_cctItem(new TitledSliderItem(QString(), this))
+    , m_nightShiftSpacerItem(new QSpacerItem(0, 10))
+    , m_nightTipsSpacerItem(new QSpacerItem(0, 6))
+    , m_nightManualSpacerItem(new QSpacerItem(0, 20))
 {
     m_centralLayout->setMargin(0);
     m_centralLayout->setSpacing(0);
@@ -75,6 +78,7 @@ BrightnessWidget::BrightnessWidget(QWidget *parent)
     //~ contents_path /display/Auto Brightness
     m_autoLightMode->setTitle(tr("Auto Brightness"));
     m_autoLightMode->addBackground();
+    m_autoLightMode->setVisible(false);
     m_centralLayout->addWidget(m_autoLightMode);
 
     m_centralLayout->addSpacerItem(m_colorSpacerItem);
@@ -84,7 +88,7 @@ BrightnessWidget::BrightnessWidget(QWidget *parent)
     //~ contents_path /display/Night Shift
     m_nightShift->setTitle(tr("Night Shift"));
     m_nightShift->addBackground();
-    m_centralLayout->addSpacing(10);
+    m_centralLayout->addSpacerItem(m_nightShiftSpacerItem);
     m_centralLayout->addWidget(m_nightShift);
 
     m_nightTips = new DTipLabel(tr("The screen hue will be auto adjusted according to your location"), m_tempratureColorWidget);
@@ -95,7 +99,7 @@ BrightnessWidget::BrightnessWidget(QWidget *parent)
     m_nightTips->adjustSize();
     m_nightTips->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
     m_nightTips->setContentsMargins(10, 0, 0, 0);
-    m_centralLayout->addSpacing(6);
+    m_centralLayout->addSpacerItem(m_nightTipsSpacerItem);
     m_centralLayout->addWidget(m_nightTips);
 
     //~ contents_path /display/Change Color Temperature
@@ -103,7 +107,7 @@ BrightnessWidget::BrightnessWidget(QWidget *parent)
     m_cctItem->setAnnotations({tr("Cool"), "", tr("Warm")});
     m_settingsGroup->appendItem(m_nightManual);
     m_settingsGroup->appendItem(m_cctItem);
-    m_centralLayout->addSpacing(20);
+    m_centralLayout->addSpacerItem(m_nightManualSpacerItem);
     m_centralLayout->addWidget(m_settingsGroup);
 
     m_tempratureColorWidget->setLayout(m_centralLayout);
@@ -152,8 +156,8 @@ void BrightnessWidget::setMode(DisplayModel *model)
         m_autoLightSpacerItem->changeSize(0, model->autoLightAdjustIsValid() ? 10 : 0);
         m_autoLightMode->setVisible(model->autoLightAdjustIsValid());
         m_autoLightMode->setChecked(model->isAudtoLightAdjust());
-        setColorTemperatureVisible(model->redshiftIsValid());
         setAdjustCCTmode(model->adjustCCTMode()); //0不调节色温  1  自动调节   2手动调节
+        setColorTemperatureVisible(model->redshiftIsValid());
     } else {
         setColorTemperatureVisible(false);
     }
@@ -163,12 +167,15 @@ void BrightnessWidget::setMode(DisplayModel *model)
 
 void BrightnessWidget::setColorTemperatureVisible(bool visible)
 {
+    m_nightShiftSpacerItem->changeSize(0, visible ? 10 : 0);
+    m_nightTipsSpacerItem->changeSize(0, visible ? 6 : 0);
+    m_nightManualSpacerItem->changeSize(0, visible ? 20 : 0);
     m_nightShift->setVisible(visible);
     m_tempratureColorTitle->setVisible(visible);
     m_tempratureColorWidget->setVisible(visible);
     m_nightTips->setVisible(visible);
     m_nightManual->setVisible(visible);
-    m_cctItem->setVisible(visible);
+    m_cctItem->setVisible(visible && m_displayModel->adjustCCTMode() == 2);
 }
 
 void BrightnessWidget::setAdjustCCTmode(int mode)
@@ -198,7 +205,8 @@ void BrightnessWidget::showBrightness(Monitor *monitor)
         }
     }
     m_brightnessTitle->setVisible(bTitle);
-    m_colorSpacerItem->changeSize(0, bTitle ? 20 : 0);
+    //色温模块不显示的时候 设置空白区域高度为0
+    m_colorSpacerItem->changeSize(0, bTitle && ("Hidden" != GSettingWatcher::instance()->getStatus("displayColorTemperature")) && m_displayModel->redshiftIsValid() ? 20 : 0);
 }
 
 void BrightnessWidget::addSlider()
@@ -272,6 +280,7 @@ void BrightnessWidget::addSlider()
                 m_miniScales = 1;
             }
             double brightness = monList[i]->brightness();
+            slideritem->setValueLiteral(brightnessToTickInterval(brightness));
             slider->setRange(m_miniScales, maxBacklight);
             slider->setType(DCCSlider::Vernier);
             slider->setTickPosition(QSlider::TicksBelow);
@@ -299,6 +308,7 @@ void BrightnessWidget::addSlider()
 
             connect(monList[i], &Monitor::brightnessChanged, this, [=](const double rb) {
                 slider->blockSignals(true);
+                slideritem->setValueLiteral(brightnessToTickInterval(rb));
                 if ((rb - m_displayModel->minimumBrightnessScale()) < 0.00001) {
                     slider->setValue(int((m_displayModel->minimumBrightnessScale() + DoubleZero) * maxBacklight));
                 } else {
