@@ -209,13 +209,19 @@ void DisplayModule::showSingleScreenWidget()
     BrightnessWidget *brightnessWidget = new BrightnessWidget(singleScreenWidget);
     brightnessWidget->setMode(m_displayModel);
     contentLayout->addWidget(brightnessWidget);
-    brightnessWidget->setVisible(m_displayModel->brightnessEnable());
+    bool canBrightness = std::any_of(m_displayModel->monitorList().begin(), m_displayModel->monitorList().end(), [](Monitor* moi){
+        if(moi->enable()){
+            return moi->canBrightness();
+        }
+    });
+    const bool brightnessIsEnabled = m_displayModel->brightnessEnable() && canBrightness;
+    brightnessWidget->setVisible(brightnessIsEnabled);
     connect(brightnessWidget, &BrightnessWidget::requestSetColorTemperature, m_displayWorker, &DisplayWorker::setColorTemperature);
     connect(brightnessWidget, &BrightnessWidget::requestSetMonitorBrightness, m_displayWorker, &DisplayWorker::setMonitorBrightness);
     connect(brightnessWidget, &BrightnessWidget::requestAmbientLightAdjustBrightness, m_displayWorker, &DisplayWorker::setAmbientLightAdjustBrightness);
     connect(brightnessWidget, &BrightnessWidget::requestSetMethodAdjustCCT, m_displayWorker, &DisplayWorker::SetMethodAdjustCCT);
 
-    QSpacerItem *scalingSpacerItem = new QSpacerItem(0, m_displayModel->brightnessEnable() ? 20 : 0);
+    QSpacerItem *scalingSpacerItem = new QSpacerItem(0, brightnessIsEnabled? 20 : 0);
     contentLayout->addSpacerItem(scalingSpacerItem);
 
     ScalingWidget *scalingWidget = new ScalingWidget(singleScreenWidget);
@@ -258,9 +264,16 @@ void DisplayModule::showSingleScreenWidget()
     singleScreenWidget->setLayout(contentLayout);
     m_displayWidget->setContent(singleScreenWidget);
 
-    connect(m_displayModel, &DisplayModel::brightnessEnableChanged, this, [brightnessWidget, scalingSpacerItem](const bool enable) {
-        scalingSpacerItem->changeSize(0, enable ? 20 : 0);
-        brightnessWidget->setVisible(enable);
+    connect(m_displayModel, &DisplayModel::brightnessEnableChanged, this, [brightnessWidget, scalingSpacerItem, this](const bool enable) {
+        bool canBrightness = std::any_of(m_displayModel->monitorList().begin(), m_displayModel->monitorList().end(), [](Monitor* moi){
+            if(moi->enable()){
+                return moi->canBrightness();
+            }
+        });
+
+        const bool visible = enable && canBrightness;
+        scalingSpacerItem->changeSize(0, visible ? 20 : 0);
+        brightnessWidget->setVisible(visible);
     });
 }
 
@@ -362,7 +375,12 @@ void DisplayModule::onRequestSetResolution(Monitor *monitor, const int mode)
         } else {
             m_displayWorker->setMonitorResolution(tmon, tmode.id());
         }
-        m_displayWorker->applyChanges();
+
+        // 扩展模式调整分辨率时会再次调整显示屏位置，此时会调用两次applyChanges接口，
+        // 修改分辨率调用applyChanges后任务栏会响应分辨率改变信号，然后调整大小，造成部分界面显示到第二个屏幕
+        // 只有一个屏幕时displayMode可能是EXTEND_MODE，同时需要判断显示数量
+        if (m_displayModel->displayMode() != EXTEND_MODE || m_displayModel->monitorList().size() < 2)
+            m_displayWorker->applyChanges();
     };
 
     tfunc(monitor, firstRes);
@@ -505,7 +523,16 @@ void DisplayModule::initSearchData()
     };
 
     auto func_brightnessEnable_changed = [ = ] {
-        bool isBrightnessEnable = func_is_visible("brightnessEnable", false);
+        // 是否有支持调节亮度的屏幕，如果没有则不显示亮度模块
+        bool haveMonitorCanBrightness = false;
+        for (auto monitor : m_displayModel->monitorList()) {
+            if (monitor->enable() && monitor->canBrightness()) {
+                haveMonitorCanBrightness = true;
+                break;
+            }
+        }
+
+        bool isBrightnessEnable = haveMonitorCanBrightness && func_is_visible("brightnessEnable", false);
         qDebug() << Q_FUNC_INFO << "autoLightAdjustIsValid:::" << m_displayModel->autoLightAdjustIsValid();
         m_frameProxy->setWidgetVisible(module, tr("Auto Brightness"), isBrightnessEnable && func_is_visible("displayLightLighting")
                                        && m_displayModel->autoLightAdjustIsValid() && !IsServerSystem);
@@ -514,6 +541,7 @@ void DisplayModule::initSearchData()
         m_frameProxy->setWidgetVisible(module, tr("Color Temperature"), isBrightnessEnable && func_is_visible("displayColorTemperature")  && m_displayModel->redshiftIsValid());
         m_frameProxy->setWidgetVisible(module, tr("Night Shift"), isBrightnessEnable && func_is_visible("displayColorTemperature") && m_displayModel->redshiftIsValid());
         m_frameProxy->setWidgetVisible(module, tr("Change Color Temperature"), isBrightnessEnable && func_is_visible("displayColorTemperature") && m_displayModel->redshiftIsValid());
+        m_frameProxy->updateSearchData(module);
     };
 
     auto func_process_all = [ = ]() {
@@ -587,6 +615,14 @@ void DisplayModule::initSearchData()
         m_frameProxy->setWidgetVisible(module, tr("Night Shift"), func_is_visible("brightnessEnable", false) && func_is_visible("displayColorTemperature"));
         m_frameProxy->setWidgetVisible(module, tr("Change Color Temperature"), func_is_visible("brightnessEnable", false) && func_is_visible("displayColorTemperature"));
     });
+    connect(m_displayModel, &DisplayModel::displayModeChanged, this, [ = ] {
+        func_brightnessEnable_changed();
+    });
+
+    // 在多个屏幕选择仅单屏显示时，切换单屏不触发displayModeChanged，故增加判断主屏变换信号
+    connect(m_displayModel, &DisplayModel::primaryScreenChanged, this, [ = ] {
+        func_brightnessEnable_changed();
+    });
 
     func_process_all();
 }
